%define db42_version 4.2.52
%define db43_version 4.3.29
%define db4_versions %{db42_version} %{db43_version}

%define _libdb_a	libdb-${soversion}.a
%define _libcxx_a	libdb_cxx-${soversion}.a

Summary: The Berkeley DB database compatibility library
Name: compat-db
Version: 4.6.21
Release: 15%{?dist}
Source0: http://download.oracle.com/berkeley-db/db-%{db42_version}.tar.gz
Source1: http://download.oracle.com/berkeley-db/db-%{db43_version}.tar.gz

Patch1: compat-db-ac_config.patch
Patch3: db-4.5.20-sparc64.patch

# Upstream db-4.2.52 patches
Patch10: http://www.oracle.com/technology/products/berkeley-db/db/update/%{db42_version}/patch.%{db42_version}.1
Patch11: http://www.oracle.com/technology/products/berkeley-db/db/update/%{db42_version}/patch.%{db42_version}.2
Patch12: http://www.oracle.com/technology/products/berkeley-db/db/update/%{db42_version}/patch.%{db42_version}.3
Patch13: http://www.oracle.com/technology/products/berkeley-db/db/update/%{db42_version}/patch.%{db42_version}.4
Patch14: http://www.oracle.com/technology/products/berkeley-db/db/update/%{db42_version}/patch.%{db42_version}.5

# Upstream db-4.3.29 patches
Patch20: http://www.oracle.com/technology/products/berkeley-db/db/update/%{db43_version}/patch.%{db43_version}.1

URL: http://www.oracle.com/database/berkeley-db/
License: BSD
Group: System Environment/Libraries
BuildRequires: findutils, libtool, perl, sed, ed
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: compat-db42%{?_isa} = %{db42_version}-%{release}
Requires: compat-db43%{?_isa} = %{db43_version}-%{release}

%description
The Berkeley Database (Berkeley DB) is a programmatic toolkit that provides
embedded database support for both traditional and client/server applications.
This package contains various versions of Berkeley DB which were included in
previous releases of Red Hat Linux.

%package -n compat-db42
Summary: The Berkeley DB database %{db42_version} compatibility library
Group: System Environment/Libraries
Version: %{db42_version}
Obsoletes: db1, db1-devel
Obsoletes: db2, db2-devel, db2-utils
Obsoletes: db3, db3-devel, db3-utils
Obsoletes: db31, db32, db3x
Obsoletes: db4 < 4.2, db4-devel < 4.2, db4-utils < 4.2, db4-tcl < 4.2, db4-java < 4.2
Obsoletes: compat-db < 4.6.21-5

%description -n compat-db42
The Berkeley Database (Berkeley DB) is a programmatic toolkit that provides
embedded database support for both traditional and client/server applications.
This package contains Berkeley DB library version %{db42_version} used for compatibility.

%package -n compat-db43
Summary: The Berkeley DB database %{db43_version} compatibility library
Group: System Environment/Libraries
Version: %{db43_version}
Obsoletes: db1, db1-devel
Obsoletes: db2, db2-devel, db2-utils
Obsoletes: db3, db3-devel, db3-utils
Obsoletes: db31, db32, db3x
Obsoletes: db4 < 4.3, db4-devel < 4.3, db4-utils < 4.3, db4-tcl < 4.3, db4-java < 4.3
Obsoletes: compat-db < 4.6.21-5

%description -n compat-db43
The Berkeley Database (Berkeley DB) is a programmatic toolkit that provides
embedded database support for both traditional and client/server applications.
This package contains Berkeley DB library version %{db43_version} used for compatibility.

%prep
%setup -q -c -a 1

%patch1 -p1 -b .ac_config

pushd db-%{db42_version}
%patch10 -p0
%patch11 -p0
%patch12 -p0
%patch13 -p0
%patch14 -p0
popd

pushd db-%{db43_version}
%patch20 -p0
%patch3 -p1 -b .sparc64
popd

pushd db-%{db42_version}/dist
libtoolize --copy --force
for i in `ls aclocal/*.m4`; do
  mv $i `echo $i | sed s/m4$/ac/`
done
popd

mkdir docs
for version in %{db4_versions} ; do
	mkdir docs/db-${version}
	install -m644 db*${version}/{README,LICENSE} docs/db-${version}
done

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
for version in %{db4_versions} ; do
	pushd db-${version}/dist
	./s_config
	mkdir build_unix
	cd build_unix
	ln -s ../configure
	%configure --prefix=%{_prefix} \
		--enable-compat185 \
		--enable-shared --disable-static \
		--enable-rpc \
		--enable-cxx
	soversion=`echo ${version} | cut -f1,2 -d.`
	make libdb=%{_libdb_a} libcxx=%{_libcxx_a} %{?_smp_mflags}
	popd
done

# remove dangling tags symlink from examples.
rm -f examples_cxx/tags
rm -f examples_c/tags

%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}%{_bindir}
mkdir -p ${RPM_BUILD_ROOT}%{_libdir}

for version in %{db4_versions} ; do
	pushd db-${version}/dist/build_unix
	%makeinstall libdb=%{_libdb_a} libcxx=%{_libcxx_a}
	# Move headers to special directory to avoid conflicts
	mkdir -p ${RPM_BUILD_ROOT}%{_includedir}/db${version}
	mv db.h db_185.h db_cxx.h ${RPM_BUILD_ROOT}%{_includedir}/db${version}
	# Rename the utilities.
	major=`echo ${version} | cut -c1,3`
	for bin in ${RPM_BUILD_ROOT}%{_bindir}/*db_* ; do
		t=`echo ${bin} | sed "s,db_,db${major}_,g"`
		mv ${bin} ${t}
	done
	popd
done

# Nuke non-versioned symlinks and headers
rm -f ${RPM_BUILD_ROOT}%{_libdir}/libdb-4.so \
${RPM_BUILD_ROOT}%{_libdir}/libdb.so \
${RPM_BUILD_ROOT}%{_libdir}/libdb_cxx-4.so \
${RPM_BUILD_ROOT}%{_libdir}/libdb_cxx.so \
${RPM_BUILD_ROOT}%{_includedir}/db.h \
${RPM_BUILD_ROOT}%{_includedir}/db_185.h \
${RPM_BUILD_ROOT}%{_includedir}/db_cxx.h


# Make sure all shared libraries have the execute bit set.
chmod 755 ${RPM_BUILD_ROOT}%{_libdir}/libdb*.so*

# XXX Avoid Permission denied. strip when building as non-root.
chmod u+w ${RPM_BUILD_ROOT}%{_bindir} ${RPM_BUILD_ROOT}%{_bindir}/*

# Make %{_libdir}/db<version>/libdb.so symlinks to ease detection for autofoo
for version in %{db4_versions} ; do
	mkdir -p ${RPM_BUILD_ROOT}/%{_libdir}/db${version}
	pushd ${RPM_BUILD_ROOT}/%{_libdir}/db${version}
	ln -s ../../../%{_lib}/libdb-`echo ${version} | cut -b 1-3`.so libdb.so
	ln -s ../../../%{_lib}/libdb_cxx-`echo ${version} | cut -b 1-3`.so libdb_cxx.so
	popd
done


# On Linux systems, move the shared libraries to lib directory.
%ifos linux
if [ "%{_libdir}" != "%{_lib}" ]; then
	mkdir -p ${RPM_BUILD_ROOT}/%{_lib}
	mv ${RPM_BUILD_ROOT}%{_libdir}/libdb*?.?.so* ${RPM_BUILD_ROOT}/%{_lib}/
fi
%endif

# Remove unpackaged files.
rm -fr ${RPM_BUILD_ROOT}%{_libdir}/*.a
rm -fr ${RPM_BUILD_ROOT}%{_libdir}/*.la
rm -fr ${RPM_BUILD_ROOT}%{_prefix}/docs/

%clean
rm -rf ${RPM_BUILD_ROOT}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)

%files -n compat-db42
%doc docs/db-%{db42_version}
%{_bindir}/db42*
%{_bindir}/berkeley_db42_svc
%ifos linux
/%{_lib}/libdb-4.2.so
/%{_lib}/libdb_cxx-4.2.so
%else
%{_libdir}/libdb-4.2.so
%{_libdir}/libdb_cxx-4.2.so
%endif
%{_libdir}/db%{db42_version}
%{_includedir}/db%{db42_version}

%files -n compat-db43
%doc docs/db-%{db43_version}
%{_bindir}/db43*
%{_bindir}/berkeley_db43_svc
%ifos linux
/%{_lib}/libdb-4.3.so
/%{_lib}/libdb_cxx-4.3.so
%else
%{_libdir}/libdb-4.3.so
%{_libdir}/libdb_cxx-4.3.so
%endif
%{_libdir}/db%{db43_version}
%{_includedir}/db%{db43_version}


%changelog

